@@ -13,6 +13,7 @@
 \\with-dimensions
 \\with-color
 \\with
+\\whiteout-box
 \\whiteout
 \\whiteTriangleMarkup
 \\walkerHeadsMinor
@@ -524,6 +525,7 @@
 \\flexa
 \\flat
 \\flageolet
+\\fixed
 \\firstClef
 \\first-visible
 \\fingeringOrientations
@@ -935,7 +937,6 @@ Clef_engraver
 Chord_tremolo_engraver
 Chord_name_engraver
 ChordNames
-ChordNameVoice
 ChoirStaff
 Breathing_sign_engraver
 Break_align_engraver
